@@ -89,7 +89,7 @@ css1
 
         self.endjs = "});\n" + self.endjs
         
-        queryArray = q.split(":")
+        queryArray = q.split("=")
         para = para.replace("=", ":")
         para = para.replace("&", ",")
         command = unquote(command)
